@@ -1,6 +1,8 @@
-import tty
-import select
 import os
+import select
+import subprocess
+import time
+import tty
 
 
 class raw():
@@ -18,6 +20,8 @@ class raw():
 
     def __exit__(self, type, value, traceback):
         if self.restore:
+            # Give the terminal time to send answerbacks
+            time.sleep(0.01)
             tty.tcsetattr(self.fd, tty.TCSAFLUSH, self.mode)
 
 
@@ -26,3 +30,13 @@ def read_blocking(fd, timeout):
         return os.read(fd, 1024)
 
     return b''
+
+
+def get_size():
+    try:
+        return os.get_terminal_size()
+    except:
+        return (
+            int(subprocess.check_output(['tput', 'cols'])),
+            int(subprocess.check_output(['tput', 'lines']))
+        )
